@@ -1,11 +1,15 @@
 from eloquentarduino.ml.data.preprocessing.pipeline.Pipeline import Pipeline
+
 from eloquentarduino.ml.data.preprocessing.pipeline.BoxCox import BoxCox
 from eloquentarduino.ml.data.preprocessing.pipeline.Diff import Diff
 from eloquentarduino.ml.data.preprocessing.pipeline.FFT import FFT
 from eloquentarduino.ml.data.preprocessing.pipeline.MinMaxScaler import MinMaxScaler
 from eloquentarduino.ml.data.preprocessing.pipeline.Norm import Norm
 from eloquentarduino.ml.data.preprocessing.pipeline.PolynomialFeatures import PolynomialFeatures
+from eloquentarduino.ml.data.preprocessing.pipeline.RFE import RFE
 from eloquentarduino.ml.data.preprocessing.pipeline.SelectKBest import SelectKBest
 from eloquentarduino.ml.data.preprocessing.pipeline.StandardScaler import StandardScaler
 from eloquentarduino.ml.data.preprocessing.pipeline.Window import Window
 from eloquentarduino.ml.data.preprocessing.pipeline.YeoJohnson import YeoJohnson
+
+from eloquentarduino.ml.data.preprocessing.pipeline.PipelineGridSearch import PipelineGridSearch
